==> webservices-osgi-2.1-b29-sources.jar: com/sun/xml/wss/provider/wsit/ServerPipeCreator.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.xml.wss.provider.wsit;

import java.util.HashMap;


import com.sun.xml.ws.api.pipe.Pipe;
import com.sun.xml.ws.api.model.SEIModel;
import com.sun.xml.ws.api.model.wsdl.WSDLPort;
import com.sun.xml.ws.api.server.WSEndpoint;
import com.sun.xml.ws.assembler.ServerPipelineHook;
import com.sun.xml.ws.policy.PolicyMap;

import com.sun.istack.NotNull;
import com.sun.xml.ws.api.BindingID;
import com.sun.xml.ws.api.pipe.Tube;
import com.sun.xml.ws.assembler.dev.ServerTubelineAssemblyContext;

/**
 * This is used by JAXWSContainer to return proper 196 security and
 *  app server monitoing pipes to the StandAlonePipeAssembler and 
 *  TangoPipeAssembler
 */
public class ServerPipeCreator extends ServerPipelineHook {
     
    public ServerPipeCreator(){
    }

    @Override
    public Pipe createSecurityPipe(PolicyMap map, SEIModel sei,
            WSDLPort port, WSEndpoint owner, Pipe tail) {

        HashMap<Object, Object> props = new HashMap<Object, Object>();

        boolean httpBinding = BindingID.XML_HTTP.equals(owner.getBinding().getBindingId());
        props.put(PipeConstants.POLICY, map);
        props.put(PipeConstants.SEI_MODEL, sei);
        props.put(PipeConstants.WSDL_MODEL, port);
        props.put(PipeConstants.ENDPOINT, owner);
        props.put(PipeConstants.NEXT_PIPE, tail);
        props.put(PipeConstants.CONTAINER, owner.getContainer());
        return new ServerSecurityPipe(props, tail, httpBinding);
    }
   
    @Override
    public 
    @NotNull
    Tube createSecurityTube(ServerTubelineAssemblyContext context) {

        HashMap<Object, Object> props = new HashMap<Object, Object>();
        boolean httpBinding = BindingID.XML_HTTP.equals(context.getEndpoint().getBinding().getBindingId());
        props.put(PipeConstants.POLICY, context.getPolicyMap());
        props.put(PipeConstants.SEI_MODEL, context.getSEIModel());
        props.put(PipeConstants.WSDL_MODEL, context.getWsdlPort());
        props.put(PipeConstants.ENDPOINT, context.getEndpoint());
        //props.put(PipeConstants.NEXT_PIPE,context.getAdaptedTubelineHead());
        props.put(PipeConstants.NEXT_TUBE, context.getTubelineHead());
        props.put(PipeConstants.CONTAINER, context.getEndpoint().getContainer());
        //TODO: Convert GF security pipes to TUBE(s).
        ServerSecurityTube serverTube = new ServerSecurityTube(props, context.getTubelineHead(), httpBinding);
        return serverTube;
    }
}

==> webservices-osgi-4.0.3-sources.jar: com/sun/xml/wss/provider/wsit/ServerPipeCreator.java <==
/*
 * Copyright (c) 1997, 2022 Oracle and/or its affiliates. All rights reserved.
 * Copyright (c) 2022 Contributors to the Eclipse Foundation
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package com.sun.xml.wss.provider.wsit;

import java.util.HashMap;


import com.sun.xml.ws.api.pipe.Pipe;
import com.sun.xml.ws.api.model.SEIModel;
import com.sun.xml.ws.api.model.wsdl.WSDLPort;
import com.sun.xml.ws.api.server.WSEndpoint;
import com.sun.xml.ws.assembler.metro.ServerPipelineHook;
import com.sun.xml.ws.policy.PolicyMap;

import com.sun.istack.NotNull;
import com.sun.xml.ws.api.BindingID;
import com.sun.xml.ws.api.pipe.Tube;
import com.sun.xml.ws.assembler.dev.ServerTubelineAssemblyContext;

/**
 * This is used by JAXWSContainer to return proper 196 security and
 *  app server monitoring pipes to the StandAlonePipeAssembler and
 *  TangoPipeAssembler
 */
public class ServerPipeCreator extends ServerPipelineHook {

    public ServerPipeCreator(){
    }

    @Override
    public Pipe createSecurityPipe(PolicyMap map, SEIModel sei,
            WSDLPort port, WSEndpoint owner, Pipe tail) {

        HashMap<String, Object> props = new HashMap<>();

        boolean httpBinding = BindingID.XML_HTTP.equals(owner.getBinding().getBindingId());
        props.put(PipeConstants.POLICY, map);
        props.put(PipeConstants.SEI_MODEL, sei);
        props.put(PipeConstants.WSDL_MODEL, port);
        props.put(PipeConstants.ENDPOINT, owner);
        props.put(PipeConstants.NEXT_PIPE, tail);
        props.put(PipeConstants.CONTAINER, owner.getContainer());
        return new ServerSecurityPipe(props, tail, httpBinding);
    }

    @Override
    public
    @NotNull
    Tube createSecurityTube(ServerTubelineAssemblyContext context) {

        HashMap<String, Object> props = new HashMap<>();
        boolean httpBinding = BindingID.XML_HTTP.equals(context.getEndpoint().getBinding().getBindingId());
        props.put(PipeConstants.POLICY, context.getPolicyMap());
        props.put(PipeConstants.SEI_MODEL, context.getSEIModel());
        props.put(PipeConstants.WSDL_MODEL, context.getWsdlPort());
        props.put(PipeConstants.ENDPOINT, context.getEndpoint());
        //props.put(PipeConstants.NEXT_PIPE,context.getAdaptedTubelineHead());
        props.put(PipeConstants.NEXT_TUBE, context.getTubelineHead());
        props.put(PipeConstants.CONTAINER, context.getEndpoint().getContainer());
        //TODO: Convert GF security pipes to TUBE(s).
        return new ServerSecurityTube(props, context.getTubelineHead(), httpBinding);
    }
}
